@@ -27,17 +27,17 @@ DEFUN_DLD(nrb_srf_basisfun__, args, nargout,"\
   octave_value_list retval, newargs;
 
   const NDArray points = args(0).array_value();
-  const Octave_map nrb = args(1).map_value();
+  const octave_scalar_map nrb = args(1).scalar_map_value();
 
   if (!error_state) 
     {
 
-      const Cell knots = nrb.contents("knots")(0).cell_value();
-      const NDArray coefs = nrb.contents("coefs")(0).array_value();
-      octave_idx_type m   = static_cast<octave_idx_type> ((nrb.contents("number")(0).vector_value())(0)) - 1; // m    = size (nrb.coefs, 2) -1;
-      octave_idx_type n   = static_cast<octave_idx_type> ((nrb.contents("number")(0).vector_value())(1)) - 1; // n    = size (nrb.coefs, 3) -1;
-      octave_idx_type p   = static_cast<octave_idx_type> ((nrb.contents("order")(0).vector_value())(0)) - 1;  // p    = nrb.order(1) -1;
-      octave_idx_type q   = static_cast<octave_idx_type> ((nrb.contents("order")(0).vector_value())(1)) - 1;  // q    = nrb.order(2) -1;
+      const Cell knots = nrb.contents("knots").cell_value();
+      const NDArray coefs = nrb.contents("coefs").array_value();
+      octave_idx_type m   = static_cast<octave_idx_type> ((nrb.contents("number").vector_value())(0)) - 1; // m    = size (nrb.coefs, 2) -1;
+      octave_idx_type n   = static_cast<octave_idx_type> ((nrb.contents("number").vector_value())(1)) - 1; // n    = size (nrb.coefs, 3) -1;
+      octave_idx_type p   = static_cast<octave_idx_type> ((nrb.contents("order").vector_value())(0)) - 1;  // p    = nrb.order(1) -1;
+      octave_idx_type q   = static_cast<octave_idx_type> ((nrb.contents("order").vector_value())(1)) - 1;  // q    = nrb.order(2) -1;
 
       Array<idx_vector> idx(dim_vector (2, 1), idx_vector(':')); 
       idx(0) = 0;
@@ -46,7 +46,7 @@ DEFUN_DLD(nrb_srf_basisfun__, args, nargout,"\
       idx(0) = 1;
       const NDArray v(points.index (idx).squeeze ()); // v = points(2,:);      
 
-      octave_idx_type npt = u.length (); // npt = length(u);
+      octave_idx_type npt = u.numel (); // npt = length(u);
       RowVector M(p+1, 0.0), N (q+1, 0.0);
       Matrix RIkJk(npt, (p+1)*(q+1), 0.0);
       Matrix indIkJk(npt, (p+1)*(q+1), 0.0);
@@ -69,7 +69,7 @@ DEFUN_DLD(nrb_srf_basisfun__, args, nargout,"\
       Matrix Ik = feval (std::string("numbasisfun"), newargs, 1)(0).matrix_value (); // Ik = numbasisfun (spu, u, p, U);
 
       RowVector spv(v);
-      for (octave_idx_type ii(0); ii < v.length(); ii++)
+      for (octave_idx_type ii(0); ii < v.numel (); ii++)
 	{
 	  spv(ii) = findspan(n, q, v(ii), V);
 	} // spv  =  findspan (n, q, v, V);
@@ -84,7 +84,7 @@ DEFUN_DLD(nrb_srf_basisfun__, args, nargout,"\
 	  NuIkuk.insert (M, ii, 0);
 	} // NuIkuk = basisfun (spu, u, p, U);
 
-      Matrix NvJkvk(v.length (), q+1, 0.0);
+      Matrix NvJkvk(v.numel (), q+1, 0.0);
       for (octave_idx_type ii(0); ii < npt; ii++)
 	{
 	  basisfun(int(spv(ii)), v(ii), q, V, N);
